@@ -20,8 +20,8 @@ class Config {
   static std::optional<std::string> findConfigPath(
       const std::vector<std::string> &names, const std::vector<std::string> &dirs = CONFIG_DIRS);
 
-  static std::optional<std::string> tryExpandPath(const std::string &base,
-                                                  const std::string &filename);
+  static std::vector<std::string> tryExpandPath(const std::string &base,
+                                                const std::string &filename);
 
   Config() = default;
 
