@@ -10,8 +10,8 @@ namespace waybar::modules {
 class Clock : public ALabel {
  public:
   Clock(const std::string&, const Json::Value&);
-  ~Clock() = default;
-  auto update() -> void;
+  virtual ~Clock() = default;
+  auto update() -> void override;
 
  private:
   util::SleeperThread thread_;
