@@ -12,12 +12,12 @@ namespace waybar::modules {
 class Sndio : public ALabel {
  public:
   Sndio(const std::string &, const Json::Value &);
-  ~Sndio();
-  auto update() -> void;
+  virtual ~Sndio();
+  auto update() -> void override;
   auto set_desc(struct sioctl_desc *, unsigned int) -> void;
   auto put_val(unsigned int, unsigned int) -> void;
-  bool handleScroll(GdkEventScroll *);
-  bool handleToggle(GdkEventButton *const &);
+  bool handleScroll(GdkEventScroll *) override;
+  bool handleToggle(GdkEventButton *const &) override;
 
  private:
   auto connect_to_sndio() -> void;
