@@ -13,8 +13,8 @@ namespace waybar::modules::SNI {
 class Tray : public AModule {
  public:
   Tray(const std::string&, const Bar&, const Json::Value&);
-  ~Tray() = default;
-  auto update() -> void;
+  virtual ~Tray() = default;
+  auto update() -> void override;
 
  private:
   void onAdd(std::unique_ptr<Item>& item);
