@@ -56,7 +56,8 @@ auto waybar::modules::Memory::update() -> void {
       event_box_.show();
       auto icons = std::vector<std::string>{state};
       label_.set_markup(fmt::format(
-          format, used_ram_percentage, fmt::arg("icon", getIcon(used_ram_percentage, icons)),
+          fmt::runtime(format), used_ram_percentage,
+          fmt::arg("icon", getIcon(used_ram_percentage, icons)),
           fmt::arg("total", total_ram_gigabytes), fmt::arg("swapTotal", total_swap_gigabytes),
           fmt::arg("percentage", used_ram_percentage),
           fmt::arg("swapPercentage", used_swap_percentage), fmt::arg("used", used_ram_gigabytes),
@@ -68,8 +69,8 @@ auto waybar::modules::Memory::update() -> void {
       if (config_["tooltip-format"].isString()) {
         auto tooltip_format = config_["tooltip-format"].asString();
         label_.set_tooltip_text(fmt::format(
-            tooltip_format, used_ram_percentage, fmt::arg("total", total_ram_gigabytes),
-            fmt::arg("swapTotal", total_swap_gigabytes),
+            fmt::runtime(tooltip_format), used_ram_percentage,
+            fmt::arg("total", total_ram_gigabytes), fmt::arg("swapTotal", total_swap_gigabytes),
             fmt::arg("percentage", used_ram_percentage),
             fmt::arg("swapPercentage", used_swap_percentage), fmt::arg("used", used_ram_gigabytes),
             fmt::arg("swapUsed", used_swap_gigabytes), fmt::arg("avail", available_ram_gigabytes),
